@@ -16,13 +16,26 @@
 import os
 import shutil
 
+from .config import ConfigObject
+from .dirinfo import DirInfo
+from .logman import LogManager
 from .statusbar import StatusBar
 from .utils import getString
 
 
 class FileManager:
-    def __init__(self):
-        raise Exception("ERROR: FileManager should be inheritted by BackupManager, never instantiated directly")
+    # expose the copy function as a class attribute for easy monkey-patching
+    copy_function = shutil.copy2
+
+    def __init__(self, config: ConfigObject, source: DirInfo, dest: DirInfo, log: LogManager, backup_time: int, gui: bool):
+        """Provides file operation methods (used by BackupManager)"""
+        # init variables
+        self.log = log
+        self.backup_time = backup_time
+        self.gui = gui
+        self.config = config
+        self.source = source
+        self.dest = dest
 
     ##########################################################################
     # Basic file operation methods (only these methods touch files directly) #
@@ -58,7 +71,7 @@ class FileManager:
                 else:
                     if not os.path.isdir(os.path.dirname(dest)):
                         os.makedirs(os.path.dirname(dest))
-                    shutil.copy2(source, dest)
+                    FileManager.copy_function(source, dest)
                     if self.config.verify_copy:
                         self.source.verifyCrcOnCopy(source_root, dest_root, source_file, dest_file, self.dest)
         except Exception as e:
@@ -88,13 +101,13 @@ class FileManager:
     ##########################################################################
 
     def removeFiles(self, root_path: str, file_relative_paths: list) -> None:
-        self.colourPrint(getString("Removing %s unique files from:\n%s") % (len(file_relative_paths), root_path), "OKBLUE")
+        self.log.colourPrint(getString("Removing %s unique files from:\n%s") % (len(file_relative_paths), root_path), "OKBLUE")
         for f in file_relative_paths:
             self.removeFile(root_path, f)
-        self.colourPrint(getString("Removal completed!"), "NONE")
+        self.log.colourPrint(getString("Removal completed!"), "NONE")
 
     def copyFiles(self, source_root: str, dest_root: str, source_files: str, dest_files: str) -> None:
-        self.colourPrint(getString("Copying %s unique files from:\n%s\nto:\n%s") % (len(source_files), source_root, dest_root), "OKBLUE")
+        self.log.colourPrint(getString("Copying %s unique files from:\n%s\nto:\n%s") % (len(source_files), source_root, dest_root), "OKBLUE")
         copy_status = StatusBar("Copying", len(source_files), self.config.stdout_status_bar, gui=self.gui)
         for i in range(len(source_files)):
             copy_status.update(source_files[i])
@@ -102,10 +115,10 @@ class FileManager:
         copy_status.endProgress()
 
     def moveFiles(self, source_root: str, dest_root: str, source_files: str, dest_files: str) -> None:
-        self.colourPrint(getString("Archiving %s unique files from:\n%s") % (len(source_files), source_root), "OKBLUE")
+        self.log.colourPrint(getString("Archiving %s unique files from:\n%s") % (len(source_files), source_root), "OKBLUE")
         for i in range(len(source_files)):
             self.moveFile(source_root, dest_root, source_files[i], dest_files[i])
-        self.colourPrint(getString("Archiving completed!"), "NONE")
+        self.log.colourPrint(getString("Archiving completed!"), "NONE")
 
     def handleDeletedFiles(self, root_path: str, file_relative_paths: list) -> None:
         if self.config.noarchive:
@@ -118,7 +131,7 @@ class FileManager:
         if not self.config.nomoves:
             # conflicts shouldn't happen since moved is a subset of files from source_only and dest_only
             # depends on source_info.dirCompare(dest_info) otherwise source and dest keys will be reversed
-            self.colourPrint(getString("Moving %s files on destination to match source") % (len(moved_pairs)), "OKBLUE")
+            self.log.colourPrint(getString("Moving %s files on destination to match source") % (len(moved_pairs)), "OKBLUE")
             for f in moved_pairs:
                 if reverse:
                     dest = self.config.source
@@ -129,7 +142,7 @@ class FileManager:
                     oldLoc = f["dest"]
                     newLoc = f["source"]
                 self.moveFile(dest, dest, oldLoc, newLoc)
-            self.colourPrint(getString("Moving completed!"), "NONE")
+            self.log.colourPrint(getString("Moving completed!"), "NONE")
 
     def archiveFile(self, root_path: str, file_relative_path: str) -> None:
         if not self.config.noarchive:
@@ -137,7 +150,7 @@ class FileManager:
             self.moveFile(root_path, archive_path, file_relative_path, file_relative_path)
 
     def handleChangedFiles(self, source_root: str, dest_root: str, source_dict: dict, dest_dict: dict, changed: list) -> None:
-        self.colourPrint(getString("Handling %s file changes per selection mode") % (len(changed)), "OKBLUE")
+        self.log.colourPrint(getString("Handling %s file changes per selection mode") % (len(changed)), "OKBLUE")
         copy_status = StatusBar("Copying", len(changed), self.config.stdout_status_bar, gui=self.gui)
         for frp in changed:
             copy_status.update(frp)
